@@ -14,10 +14,18 @@ class ISLocale(Locale):
   def initialize(self):
     self.text_domain = 'interface-switcher'
     self.current_dict = {
+      'item-Bluetooth': 'Bluetooth',
+      'item-GSM': 'GSM',
+      'item-WLAN': 'WLAN',
       'item-On': 'On',
       'item-Off': 'Off',
       'item-Connected':  'Connected',
       'item-<>':  '<>',
+      'item-3G+GSM':  '3G+GSM',
+      'item-GSM':  '2G',
+      'item-3G':  '3G',
+      'item-Connectable': 'Connectable',
+      'item-Discoverable': 'Discoverable'
     }
 
 islocale_singleton = ISLocale()
